Check that primary forest (primf) and primary nature/nonland (primf) are never expanding using toolExpectTrue. If they are expanding, a warning including the maximum expansion is thrown. Categories not present in x are skipped.
Check that primary forest (primf) and primary nature/nonland (primf) are never expanding using toolExpectTrue. If they are expanding, a warning including the maximum expansion is thrown. Categories not present in x are skipped.