Skip to content

Warn if expansion is detected one of the given variables, giving the maximum expansion in each respective variable.

Usage

toolWarnIfExpansion(x, variable)

Arguments

x

A magclass object

variable

A vector of variables to be checked

Author

Pascal Sauer