Aggregated low resolution target data is extrapolated to the given years using toolExtrapolate and normalized afterwards, so that the total sum over all land types is unchanged. To account for the relationship between wood harvest area and primary land (which is no longer primary once it has been harvested) wood harvest area is calculated here even though it is a nonland variable. The share of woody land that was harvested in the historical period is calculated and then multiplied by land (already extrapolated). Primary land is then converted to secondary land, so that total reduction equals harvested area.