calcNonlandInputRecategorized
Source:R/calcNonlandInputRecategorized.R
calcNonlandInputRecategorized.RdHarmonize categories by mapping nonland input data categories to the categories of the nonland target dataset.
See calcLandInputRecategorized for an explanation of the mapping procedure.
Usage
calcNonlandInputRecategorized(
input,
target,
youngShareWoodHarvestArea = 0.95,
youngShareWoodHarvestWeight = 0.5
)Arguments
- input
name of an input dataset, currently only "magpie"
- target
name of a target dataset, see
calcLandTargetfor available target datasetsshare of wood harvest area taken from young (instead of mature) secondary forest; default value is based on LUH value from 2014; used to disaggregate wood harvest area from secondary forest to secondary young and mature forest
analogue to youngShareWoodHarvestArea for wood harvest weight instead of area