Prepare the high resolution nonland target dataset for harmonization and downscaling, checking data for consistency before returning.
Arguments
- target
name of a target dataset, see
calcLandTargetfor available target datasets- endOfHistory
years later than this are not returned