Tool function for creating a harmonized data set with a smooth s-shaped transition from historic target data to simulated input data.
Arguments
- xInput
input data as magpie object
- xTarget
target data as magpie object
- harmonizationPeriod
Two integer values, before the first given year the target dataset is used, after the second given year the input dataset is used, in between harmonize between the two datasets
- level
passed to toolReplaceExpansion