Harmonize using toolHarmonizeFade, then sum up primf + secdf,
then disaggregate again in a way that minimizes primf to secdf conversion,
without exceeding linear extrapolation of primf.
Harmonize using toolHarmonizeFade, then sum up primf + secdf,
then disaggregate again in a way that minimizes primf to secdf conversion,
without exceeding linear extrapolation of primf.