R/toolWarnIfExpansion.R
toolWarnIfExpansion.Rd
Warn if expansion is detected one of the given variables, giving the maximum expansion in each respective variable.
toolWarnIfExpansion(x, variable)
A magclass object
A vector of variables to be checked
Pascal Sauer